/*	Copyright (C) 2003-2013 Free Electron Organization
	Any use of this software requires a license.  If a valid license
	was not distributed with this file, visit freeelectron.org. */

/** @file */

#include "operator.pmh"
#include "platform/dlCore.cc"

using namespace fe;

extern "C"
{

FE_DL_EXPORT void ListDependencies(List<String*>& list)
{
	list.append(new String("fexOperateDL"));
	list.append(new String("fexRayDL"));
	list.append(new String("fexJsonDL"));
	list.append(new String("fexXmlDL"));
//	list.append(new String("fexOIIODL"));	//* links to native boost
	list.append(new String("fexOpenILDL"));
	list.append(new String("fexTiffDL"));
}

FE_DL_EXPORT Library* CreateLibrary(sp<Master> spMaster)
{
	assertMath(spMaster->typeMaster());

	Library *pLibrary = new Library();

	pLibrary->add<TransformManipulator>(
			"ManipulatorI.TransformManipulator.fe");
	pLibrary->add<ValueManipulator>(
			"ManipulatorI.ValueManipulator.fe");

	pLibrary->add<BloatOp>(
			"OperatorSurfaceI.BloatOp.fe");
	pLibrary->add<ClaspOp>(
			"OperatorSurfaceI.ClaspOp.fe");
	pLibrary->add<ConnectOp>(
			"OperatorSurfaceI.ConnectOp.fe");
	pLibrary->add<ExcarnateOp>(
			"OperatorSurfaceI.ExcarnateOp.fe");
	pLibrary->add<GroupOp>(
			"OperatorSurfaceI.GroupOp.fe");
	pLibrary->add<HammerOp>(
			"OperatorSurfaceI.HammerOp.fe");
	pLibrary->add<HobbleOp>(
			"OperatorSurfaceI.HobbleOp.fe");
	pLibrary->add<ImportOp>(
			"OperatorSurfaceI.ImportOp.fe");
	pLibrary->add<LengthCorrectOp>(
			"OperatorSurfaceI.LengthCorrectOp.fe");
	pLibrary->add<OffsetOp>(
			"OperatorSurfaceI.OffsetOp.fe");
	pLibrary->add<PuppetOp>(
			"OperatorSurfaceI.PuppetOp.fe");
	pLibrary->add<QuiltOp>(
			"OperatorSurfaceI.QuiltOp.fe");
	pLibrary->add<RasterOp>(
			"OperatorSurfaceI.RasterOp.fe");
	pLibrary->add<SpreadsheetOp>(
			"OperatorSurfaceI.SpreadsheetOp.fe");
	pLibrary->add<SubdivideOp>(
			"OperatorSurfaceI.SubdivideOp.fe");
	pLibrary->add<SurfaceAttrCopyOp>(
			"OperatorSurfaceI.SurfaceAttrCopyOp.fe");
	pLibrary->add<SurfaceAttrLabOp>(
			"OperatorSurfaceI.SurfaceAttrLabOp.fe");
	pLibrary->add<SurfaceBindOp>(
			"OperatorSurfaceI.SurfaceBindOp.fe");
	pLibrary->add<SurfaceMetricOp>(
			"OperatorSurfaceI.SurfaceMetricOp.fe");
	pLibrary->add<SurfaceNormalOp>(
			"OperatorSurfaceI.SurfaceNormalOp.fe");
	pLibrary->add<SurfaceSampleOp>(
			"OperatorSurfaceI.SurfaceSampleOp.fe");
	pLibrary->add<SurfaceWrapOp>(
			"OperatorSurfaceI.SurfaceWrapOp.fe");

	pLibrary->add<CurveCreateOp>(
			"OperatorSurfaceI.CurveCreateOp.fe.nohoudini");
	pLibrary->add<PartitionOp>(
			"OperatorSurfaceI.PartitionOp.fe.nohoudini");
	pLibrary->add<SurfaceAttrCreateOp>(
			"OperatorSurfaceI.SurfaceAttrCreateOp.fe.nohoudini");
	pLibrary->add<SurfaceCopyOp>(
			"OperatorSurfaceI.SurfaceCopyOp.fe.nohoudini");
	pLibrary->add<SurfaceSummaryOp>(
			"OperatorSurfaceI.SurfaceSummaryOp.fe.nohoudini");

	pLibrary->add<FollicleOp>(
			"OperatorSurfaceI.FollicleOp.fe.prototype");

	return pLibrary;
}

}
